@@ -53,7 +53,7 @@ def update(opml, cache, service):
 
     try:
         #{ Update service account subscription data
-        for index, title in (Refresh(cache=cache, opml=opml)):
+        for index, title in (Refresh(cache=cache, path=opml)):
             print "    * %s." % service.PRETITLE.sub("", title)
 
     except cache.CacheException as error:
@@ -94,7 +94,7 @@ def compose(opml, directory, form, cache, service):
         try:
             #{ Write serial audio date with Forms Composer
             for item in composer.write(data=Xml.opml(cache.Cache(opml).data()),
-                filename=composer.FILENAME, workstore=(cache.HOMEDIR 
+                filepath=composer.FILENAME, workpath=(cache.HOMEDIR 
                 if directory == "~" or not directory else directory),
                 cache=cache, service=service):
                 print("Formatting feed: %s" % item)
