@@ -36,8 +36,8 @@ def browse(action, form, directory, cache, service):
 
     @param action: soovee.pages option. Currently [sub|all].
     @type action: basestring
-    @param format: soovee.forms option. Currently [html|opml].
-    @type format: basestring
+    @param form: soovee.forms option. Currently [html|opml].
+    @type form: basestring
     @param directory: Directory to save new page.
     @type directory: basestring
     @param cache: Initialized soovee.lib.sv_read object.
