@@ -60,12 +60,12 @@ def item(data, feed=None, service=None):
     Read mp3 file's tag info to get title and length to add #EXTINF to
     path-filename information.
 
-    @param item: mp3 filename
-    @type item: basestring
+    @param data: mp3 filename
+    @type data: basestring
     @param feed: Unused for this format. Default dict.
     @type feed: basestring
-    @param rx: Unused for this format. Default None.
-    @type rx: obj
+    @param service: Unused for this format. Default None.
+    @type service: obj
     @return:
     @rtype: basestring
     @requires: eyeD3.tag
