@@ -54,7 +54,7 @@ def write(filepath, workpath, data, cache=None, service=None):
 
     from soovee_lib.parse import Xml #: Rss data parsers
 
-    fileobj_index = open(cache.mkpath(filepath=filename, workpath=workstore),
+    fileobj_index = open(cache.mkpath(filepath=filepath, workpath=workpath),
         "w")
     fileobj_index.write("<h1>SooVee Serial Audio feeds</h1>\n<ul>\n")
 
@@ -66,7 +66,7 @@ def write(filepath, workpath, data, cache=None, service=None):
 
         #{ Write data for feed page
         filename = cache.mkpath(filepath=service.TOHTM(opml['title']), 
-            workpath=workstore, subpath="books")
+            workpath=workpath, subpath="books")
         fileobj_page = open(filename, "w")
         fileobj_page.write(
             item(opml, rss, service).encode("ascii", "xmlcharrefreplace")
@@ -91,8 +91,8 @@ def item(data, feed=None, service=None):
     @type data: dict
     @param feed: Rss data. Default dict.
     @type feed: dict
-    @param rx: Intialized soovee.regex object. Default None.
-    @type rx: obj
+    @param service: Intialized soovee.regex object. Default None.
+    @type service: obj
     @return:
     @rtype: basestring
     @raise TypeError: item or feed passed was not a dict
