@@ -49,8 +49,8 @@ def window(cache, service, account):
     Parse and compose a display for that accounts serial audio feeds. Provide
     controls to update, download, and listen to serial audio episodes.
 
-    @param cacheobj: Initialized soovee_lib.cache object.
-    @type cacheobj: object
+    @param cache: Initialized soovee_lib.cache object.
+    @type cache: object
     @param service: Initialized soovee.conf.serviceConf object.
     @type service: object
     @param account: Intialized soovee.conf.Account shelf object.
