@@ -134,7 +134,7 @@ class Cache():
         @return:
         @rtype: None
         
-        @requires L{soovee_lib.mkuri}
+        @requires: L{soovee_lib.mkuri}
         """
 
         self.url = {"head": "", "body": ""}
@@ -151,8 +151,8 @@ class Cache():
         in memory, while also writing retrieved to cache file, self._workfile. 
         If hook is present, progress feedback is given.
 
-        @param pathname: Internet path-filename to retrieve original
-        @type pathname: basestring
+        @param urlpath: Internet path-filename to retrieve original
+        @type urlpath: basestring
         @keyword post: Url-encoded dictionary of values. (basestring)
         @keyword hook: Object that will recieve progress updates. (object)
         @keyword update: Switch to update cache when a local file exists. (bool)
