@@ -22,8 +22,8 @@ Rss filter to extract the correct node(s).
 
     - C{Xml(xmldata:str) -> None}
     - C{Xml.children(node:str, brake:str=None) -> str}
-    - C{{Xml.Opml(data:str)  -> list}
-    - C{{Xml.Rss(data:str)  -> list}
+    - C{Xml.Opml(data:str)  -> list}
+    - C{Xml.Rss(data:str)  -> list}
 
 @requires: xml.dom.minidom
 """
@@ -38,8 +38,8 @@ class Xml():
     
         - C{PbXml(xmldata:stre) -> None}
         - C{PbXml.children(node:str, brake=None:str) -> str}
-        - C{{Xml.Opml(data:str)  -> list}
-        - C{{Xml.Rss(data:str)  -> list}
+        - C{Xml.Opml(data:str)  -> list}
+        - C{Xml.Rss(data:str)  -> list}
     """
     def __init__(self, xmldata):
         """
@@ -64,8 +64,8 @@ class Xml():
             - B{Possible attributes:} title, text, type, xmlUrl, htmlUrl, 
                 description
 
-        @param opml: Raw unparsed Ompl file data
-        @type opml: basestring
+        @param data: Raw unparsed Ompl file data
+        @type data: basestring
         @return: List of node dictionaries in Opml data
         @rtype: list
         """
@@ -96,8 +96,8 @@ class Xml():
 
         * category despite multiple tags will return a single combined value.
 
-        @param rss: Raw unparsed Rss file data
-        @type rss: basestring
+        @param data: Raw unparsed Rss file data
+        @type data: basestring
         @return: List of node dictionaries in Rss data
         @rtype: list
         """
