@@ -17,8 +17,8 @@
 """ 
 SooVee Serial Audio Manager - Cache progress hook library.
 
-    - C{Hook(obj:obj, service:obj)
-    - C{Hook.report(blockread:int, blocksize:int, filesize:int)
+    - C{Hook(obj:obj, service:obj) -> None}
+    - C{Hook.report(blockread:int, blocksize:int, filesize:int) -> None}
 """
 
 class Hook(object):
